@@ -109,10 +109,15 @@ def event_dates(obj):
         return
 
     event_days = set()
-    occurences = expand_events([obj], RET_MODE_ACCESSORS)
+    occurences = [obj]
+    if obj.recurrence:
+        next_occurences = expand_events([obj], RET_MODE_ACCESSORS)
+        occurences = [obj] + next_occurences
     for occurence in occurences:
         start = occurence.start
         event_days.add(start.date().strftime("%Y-%m-%d"))
+        if occurence.open_end:
+            continue
         end = occurence.end
         duration = (end.date() - start.date()).days
         for idx in range(1, duration + 1):
@@ -122,6 +127,16 @@ def event_dates(obj):
     return tuple(event_days)
 
 
+@indexer(IEvent)
+def first_start(obj):
+    return obj.start
+
+
+@indexer(IEvent)
+def first_end(obj):
+    return obj.end
+
+
 def get_searchable_text(obj, lang):
     def get_text(lang):
         text = ""
